'use client'

import { useEffect } from 'react'
import { FiX } from 'react-icons/fi'

interface ModalButton {
  text: string
  onClick: () => void
  icon?: React.ReactNode
  className?: string
}

interface ModalProps {
  isOpen: boolean
  onClose: () => void
  title: string
  message: string
  buttons?: ModalButton[]
}

export default function Modal({ isOpen, onClose, title, message, buttons }: ModalProps) {
  useEffect(() => {
    const handleEscape = (e: KeyboardEvent) => {
      if (e.key === 'Escape') {
        onClose()
      }
    }

    if (isOpen) {
      document.addEventListener('keydown', handleEscape)
      document.body.style.overflow = 'hidden'
    }

    return () => {
      document.removeEventListener('keydown', handleEscape)
      document.body.style.overflow = 'unset'
    }
  }, [isOpen, onClose])

  if (!isOpen) return null

  return (
    <div className="fixed inset-0 bg-black/50 backdrop-blur-sm z-50 flex items-center justify-center">
      <div className="bg-white dark:bg-slate-800 rounded-3xl shadow-xl max-w-md w-full mx-4">
        <div className="p-6 border-b border-slate-200 dark:border-slate-700">
          <h2 className="text-lg font-semibold text-slate-800 dark:text-white">
            {title}
          </h2>
        </div>
        <div className="p-6 space-y-4">
          <div className="text-center">
            <p className="text-sm text-slate-600 dark:text-slate-400">
              {message}
            </p>
          </div>
          <div className="flex justify-end gap-2">
            {buttons ? (
              buttons.map((button, index) => (
                <button
                  key={index}
                  onClick={button.onClick}
                  className={button.className}
                >
                  {button.icon}
                  {button.text}
                </button>
              ))
            ) : (
              <button
                onClick={onClose}
                className="px-4 py-2 text-sm font-medium text-slate-600 dark:text-slate-300 hover:text-slate-800 dark:hover:text-white transition-colors"
              >
                Kapat
              </button>
            )}
          </div>
        </div>
      </div>
    </div>
  )
} 